---
title: Project LovU (say love in more than 100 languages)
key: prol1
tags:
 - English
 - python
 - smtp
 - auto-mailing
toc: true
---

![akshar-dave-532470-unsplash](https://ws3.sinaimg.cn/large/006tNc79gy1fvsrsf81zbj30rs06tt8s.jpg)



About Project: 

This project is a part of python projects packaging tutorial and aims to teach how to write and publish a easy python project or python package in PyPi.

LovU - functions. Currently LovU is a very simple and unfinished project and it allows users “say love” in more that 100 languages just only using one line of code.

<!--more--> 

# How to Use

LoveU supports two different mode : offline mode and online mode.

* Offline mode : Uses only the offline resourses rather than using a google translate to generate a “I love you” sentense.
* Online mode : Uses google translate to generate a “I love you” sentense and uses it in this project. However this seems to be much acc urate in some times, but requires some other extra libraries and network connection.



s

